{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Annotate and filter VCF",
            "requirements": [
                {
                    "dockerPull": "curii/clinvar-report",
                    "class": "DockerRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 10000,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005227"
                            ],
                            "version": [
                                "1.10.2"
                            ],
                            "package": "BCFtools"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "stdout": "$(inputs.vcf.nameroot).txt",
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "Reference VCF for ClinVar",
                    "id": "#annotate-vcf.cwl/clinvarvcf"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "VCF extracted from GVCF",
                    "secondaryFiles": [
                        {
                            "pattern": ".tbi",
                            "required": null
                        }
                    ],
                    "id": "#annotate-vcf.cwl/vcf"
                }
            ],
            "arguments": [
                "bcftools",
                "annotate",
                {
                    "prefix": "-a",
                    "valueFrom": "$(inputs.clinvarvcf.path)"
                },
                {
                    "prefix": "-c",
                    "valueFrom": "ID,INFO"
                },
                "$(inputs.vcf.path)",
                {
                    "valueFrom": "|",
                    "shellQuote": false
                },
                "bcftools",
                "filter",
                {
                    "prefix": "-i",
                    "valueFrom": "INFO/ALLELEID>=1"
                },
                {
                    "valueFrom": "|",
                    "shellQuote": false
                },
                "bcftools",
                "query",
                {
                    "prefix": "-f",
                    "valueFrom": "%ID\t%CHROM\t%POS\t%REF\t%ALT\t%INFO/ALLELEID\t%INFO/CLNSIG\t%INFO/CLNDN\t%INFO/AF_ESP\t%INFO/AF_EXAC\t%INFO/AF_TGP[\t%GT]\n"
                }
            ],
            "id": "#annotate-vcf.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#annotate-vcf.cwl/reporttxt",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.nameroot).txt"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Generate ClinVar Report",
            "requirements": [
                {
                    "dockerPull": "curii/clinvar-report",
                    "class": "DockerRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 10000,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2331",
                    "label": "Header for HTML report",
                    "id": "#generate-report.cwl/headhtml"
                },
                {
                    "type": "File",
                    "label": "Function used to create HTML report",
                    "id": "#generate-report.cwl/reportfunc"
                },
                {
                    "type": "string",
                    "label": "Sample Name",
                    "id": "#generate-report.cwl/sample"
                },
                {
                    "type": "File",
                    "label": "Annotated text from VCF",
                    "id": "#generate-report.cwl/sampletxt"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2331",
                    "label": "Footer for HTML report",
                    "id": "#generate-report.cwl/tailhtml"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2331",
                    "label": "ClinVar variant report",
                    "outputBinding": {
                        "glob": "*html"
                    },
                    "id": "#generate-report.cwl/report"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                "$(inputs.reportfunc)",
                "$(inputs.sampletxt)",
                "$(inputs.sample)",
                "$(inputs.headhtml)",
                "$(inputs.tailhtml)"
            ],
            "id": "#generate-report.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Convert GVCF to VCF",
            "requirements": [
                {
                    "dockerPull": "curii/clinvar-report",
                    "class": "DockerRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 10000,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005227"
                            ],
                            "version": [
                                "1.10.2"
                            ],
                            "package": "BCFtools"
                        },
                        {
                            "version": [
                                "1.10.2"
                            ],
                            "package": "HTSlib"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "GVCF generated from GATK",
                    "id": "#gvcf-to-vcf.cwl/gvcf"
                },
                {
                    "type": "string",
                    "label": "Sample Name",
                    "id": "#gvcf-to-vcf.cwl/sample"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "VCF extracted from GVCF",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        {
                            "pattern": ".tbi",
                            "required": null
                        }
                    ],
                    "id": "#gvcf-to-vcf.cwl/vcf"
                }
            ],
            "arguments": [
                "bcftools",
                "view",
                {
                    "prefix": "--min-ac",
                    "valueFrom": "1"
                },
                "$(inputs.gvcf.path)",
                {
                    "prefix": "-i",
                    "valueFrom": "AVG(GQ)>20"
                },
                {
                    "valueFrom": "-Ov"
                },
                {
                    "prefix": "-o",
                    "valueFrom": "$(inputs.sample).vcf"
                },
                {
                    "valueFrom": "&&",
                    "shellQuote": false
                },
                "bgzip",
                {
                    "valueFrom": "$(inputs.sample).vcf"
                },
                {
                    "valueFrom": "&&",
                    "shellQuote": false
                },
                "tabix",
                {
                    "valueFrom": "$(inputs.sample).vcf.gz"
                }
            ],
            "id": "#gvcf-to-vcf.cwl",
            "https://schema.org/codeRepository": "https://github.com/arvados/arvados-tutorial",
            "https://schema.org/license": "https://www.gnu.org/licenses/agpl-3.0.en.html"
        },
        {
            "class": "Workflow",
            "label": "Report generation workflow",
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "Reference VCF for ClinVar",
                    "id": "#main/clinvarvcf"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "Gathered GVCF",
                    "id": "#main/gvcf"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2331",
                    "label": "Header for HTML report",
                    "id": "#main/headhtml"
                },
                {
                    "type": "File",
                    "label": "Function used to create HTML report",
                    "id": "#main/reportfunc"
                },
                {
                    "type": "string",
                    "label": "Sample Name",
                    "id": "#main/sample"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2331",
                    "label": "Footer for HTML report",
                    "id": "#main/tailhtml"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2331",
                    "label": "ClinVar variant report",
                    "outputSource": "#main/generate-report/report",
                    "id": "#main/report"
                }
            ],
            "steps": [
                {
                    "run": "#annotate-vcf.cwl",
                    "in": [
                        {
                            "source": "#main/clinvarvcf",
                            "id": "#main/annotate/clinvarvcf"
                        },
                        {
                            "source": "#main/gvcf-to-vcf/vcf",
                            "id": "#main/annotate/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotate/reporttxt"
                    ],
                    "id": "#main/annotate"
                },
                {
                    "run": "#generate-report.cwl",
                    "in": [
                        {
                            "source": "#main/headhtml",
                            "id": "#main/generate-report/headhtml"
                        },
                        {
                            "source": "#main/reportfunc",
                            "id": "#main/generate-report/reportfunc"
                        },
                        {
                            "source": "#main/sample",
                            "id": "#main/generate-report/sample"
                        },
                        {
                            "source": "#main/annotate/reporttxt",
                            "id": "#main/generate-report/sampletxt"
                        },
                        {
                            "source": "#main/tailhtml",
                            "id": "#main/generate-report/tailhtml"
                        }
                    ],
                    "out": [
                        "#main/generate-report/report"
                    ],
                    "id": "#main/generate-report"
                },
                {
                    "run": "#gvcf-to-vcf.cwl",
                    "in": [
                        {
                            "source": "#main/gvcf",
                            "id": "#main/gvcf-to-vcf/gvcf"
                        },
                        {
                            "source": "#main/sample",
                            "id": "#main/gvcf-to-vcf/sample"
                        }
                    ],
                    "out": [
                        "#main/gvcf-to-vcf/vcf"
                    ],
                    "id": "#main/gvcf-to-vcf"
                }
            ],
            "id": "#main",
            "https://schema.org/codeRepository": "https://github.com/arvados/arvados-tutorial",
            "https://schema.org/license": "https://www.gnu.org/licenses/agpl-3.0.en.html"
        }
    ],
    "cwlVersion": "v1.1",
    "$namespaces": {
        "s": "https://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
